@@ -181,11 +181,13 @@ class WritableField(Field):
 
         try:
             if self._use_files:
+                files = files or {}
                 native = files[field_name]
             else:
                 native = data[field_name]
         except KeyError:
-            if self.default is not None:
+            if self.default is not None and not self.root.partial:
+                # Note: partial updates shouldn't set defaults
                 native = self.default
             else:
                 if self.required:
